
[![PyPi version](https://pypip.in/v/inventree/badge.png)](https://pypi.org/project/inventree/) [![Build Status](https://travis-ci.org/inventree/inventree-python.svg?branch=master)](https://travis-ci.org/inventree/inventree-python) [![Coverage Status](https://coveralls.io/repos/github/inventree/inventree-python/badge.svg?branch=master)](https://coveralls.io/github/inventree/inventree-python?branch=master)

## InvenTree Python Interface

Python library for communication with the [InvenTree parts management system](https:///github.com/inventree/inventree) using the integrated REST API.

This library provides a class-based interface for interacting with the database. Each database table is represented as a class object which provides features analogous to the REST CRUD endpoints (Create, Retrieve, Update, Destroy).

## Installation

The InvenTree python library can be easily installed using PIP:

```
pip install inventree
```

## Documentation

Refer to the [InvenTree documentation](https://inventree.readthedocs.io/en/latest/extend/python/)
